# 43 "java/java_lexer.mll"
 

  open Java_parser
  open Lexing
  open Java_ast

  type location = position * position

  let loc lexbuf : location =
    (lexeme_start_p lexbuf, lexeme_end_p lexbuf)

  exception Lexical_error of location * string
  exception Syntax_error of location
  exception Dotdot of string


  let lex_error lexbuf s = raise (Lexical_error(loc lexbuf,s))

  let buf = Buffer.create 97

  let kw_table =
    let table = Hashtbl.create 17 in
    let _ =
      List.iter
	(fun (s,t) -> Hashtbl.add table s t)
	[ "abstract", ABSTRACT;
          "allocates", ALLOCATES;
	  "assert", ASSERT;
	  "assigns", ASSIGNS;
	  "assumes", ASSUMES;
	  "axiom", AXIOM;
	  "axiomatic", AXIOMATIC;
	  "behavior", BEHAVIOR;
	  "boolean", BOOLEAN;
	  "break", BREAK;
	  "byte", BYTE;
	  (* "byvalue", BYVALUE; ??? *)
	  "case", CASE;
	  (* "cast", CAST; ??? *)
	  "catch", CATCH;
	  "char", CHAR;
	  "class", CLASS;
	  "const", CONST;
	  "continue", CONTINUE;
	  "decreases", DECREASES;
	  "default", DEFAULT;
	  "do", DO;
	  "double", DOUBLE;
	  "else", ELSE;
	  "ensures", ENSURES;
	  "extends", EXTENDS;
	  "false", FALSE;
	  "final", FINAL;
	  "finally", FINALLY;
	  "float", FLOAT;
	  "for", FOR;
	  (* "future", FUTURE; ?? *)
	  (* "generic", GENERIC; ?? *)
	  "ghost", GHOST;
	  "goto", GOTO;
	  "if", IF;
	  "implements", IMPLEMENTS;
	  "import", IMPORT;
	  "inductive", INDUCTIVE;
	  (* "inner", INNER; ?? *)
	  "instanceof", INSTANCEOF;
	  "int", INT;
	  "integer", INTEGER;
	  "interface", INTERFACE;
	  "invariant", INVARIANT;
	  "lemma", LEMMA;
	  "logic", LOGIC;
	  "long", LONG;
	  "loop_invariant", LOOP_INVARIANT;
	  "loop_variant", LOOP_VARIANT;
	  "model", MODEL;
	  "native", NATIVE;
	  "new", NEW;
	  "non_null", NON_NULL;
	  "null", NULL;
	  "nullable", NULLABLE;
	  (* "operator", OPERATOR; ?? *)
	  (* "outer", OUTER; ?? *)
	  "package", PACKAGE;
	  "predicate", PREDICATE;
	  "private", PRIVATE;
	  "protected", PROTECTED;
	  "public", PUBLIC;
	  "reads", READS;
	  "real", REAL;
	  "requires", REQUIRES;
	  (* "rest", REST; ?? *)
	  "return", RETURN;
	  "short", SHORT;
	  "signals", SIGNALS;
	  "static", STATIC;
	  "strictfp", STRICTFP;
	  "super", SUPER;
	  "switch", SWITCH;
	  "synchronized", SYNCHRONIZED;
	  "theory", THEORY;
	  "this", THIS;
	  (* "threadsafe" ? *)
	  "throw", THROW;
	  "throws", THROWS;
	  "transient", TRANSIENT;
	  "true", TRUE;
	  "try", TRY;
	  "type", TYPE;
	  (* "var", VAR; ??? *)
	  "void", VOID;
	  "volatile", VOLATILE;
	  "while", WHILE;
	]
    in table

  let id_or_kw s =
    try
      let k = Hashtbl.find kw_table s in
      (*i
	prerr_string "Keyword ";
	prerr_endline s;
	i*)
      k
    with
	Not_found ->
	  (*i
	    prerr_string "Ident ";
	    prerr_endline s;
	    i*)
	  (ID s)

  let special_kw_table =
    let table = Hashtbl.create 17 in
    let _ =
      List.iter
	(fun (s,t) -> Hashtbl.add table s t)
	[ "\\at", BSAT;
	  "\\exists", BSEXISTS ;
	  "\\fresh", BSFRESH ;
	  "\\forall", BSFORALL ;
	  "\\nothing", BSNOTHING;
	  (*
	  "fields_of", BSFIELDSOF;
          "not_conditionally_updated", BSNOTCONDITIONALLYUPDATED;
	  *)
	  "\\old", BSOLD;
	  "\\result", BSRESULT;
	  (*"type", BSTYPE;
	  "typeof", BSTYPEOF;
	  "fpi", BSFPI; *)
	]
    in table

  let builtins_table =
    let table = Hashtbl.create 17 in
    let _ =
      List.iter
	(fun (_ty,id,_params) -> Hashtbl.add table id ())
	Java_pervasives.builtin_logic_symbols
    in table

  let special_id lexbuf s =
    try
      Hashtbl.find special_kw_table s
    with
	Not_found ->
	  try
	    let () = Hashtbl.find builtins_table s in
	    ID s
	  with
	      Not_found ->
		lex_error lexbuf ("unknown special keyword "^s)

(*

  let jml_spec_token base jml_string =
(*i
    Format.fprintf Config.log "In file %s, parsing JML Spec: %s@."
      (Location.base_filename base) jml_string;
i*)
    match Jml_syntax.parse_jml_specification base jml_string with
    | Ast_types.Jml_declaration d -> JML_DECLARATIONS(d)
    | Ast_types.Jml_method_specification s -> JML_METHOD_SPECIFICATION(s)
    | Ast_types.Jml_loop_annotation la -> JML_LOOP_ANNOTATION(la)
    | Ast_types.Jml_assertion a -> JML_ASSERTION(a)
    | Ast_types.Jml_annotation_statement Ast_types.Set_statement s -> JML_ANNOTATION_STATEMENT(Ast_types.Set_statement(s))
    | Ast_types.Jml_axiom(id,e) -> JML_AXIOM(id,e)
    | Ast_types.Jml_type(id) -> JML_TYPE(id)
    | Ast_types.Jml_logic_reads(id,t,p,r) -> JML_LOGIC_READS(id,t,p,r)
    | Ast_types.Jml_logic_def(id,t,p,e) -> JML_LOGIC_DEF(id,t,p,e)
    assert false

*)
  let newline lexbuf =
    let pos = lexbuf.lex_curr_p in
    lexbuf.lex_curr_p <-
      { pos with pos_lnum = pos.pos_lnum + 1;
	  pos_bol = pos.pos_cnum }

  let pragma lexbuf id v =
    match id with
      | "TerminationPolicy" ->
	  begin
	    Java_options.termination_policy :=
	      match v with
		| "always" -> Jc_env.TPalways
		| "user" -> Jc_env.TPuser
		| "never" -> Jc_env.TPnever
		| _ -> lex_error lexbuf ("unknown termination policy " ^ v)
	  end

      | "AbstractDomain" ->
	  begin
	    Java_options.ai_domain :=
	      match v with
		| "None" -> Jc_env.AbsNone
		| "Box" -> Jc_env.AbsBox
		| "Oct" -> Jc_env.AbsOct
		| "Pol" -> Jc_env.AbsPol
		| _ -> lex_error lexbuf ("unknown abstract domain " ^ v)
	  end
      | "AnnotationPolicy" ->
	  begin
	    Java_options.annotation_sem :=
	      match v with
		| "None" -> Jc_env.AnnotNone
		| "Invariants" -> Jc_env.AnnotInvariants
		| "WeakPre" -> Jc_env.AnnotWeakPre
		| "StrongPre" -> Jc_env.AnnotStrongPre
		| _ -> lex_error lexbuf ("unknown annotation policy " ^ v)
	  end
      | "CheckArithOverflow" ->
	  begin
	    match String.lowercase v with
	      | "yes" -> Java_options.ignore_overflow := false
	      | "no" -> Java_options.ignore_overflow := true
	      | _ -> lex_error lexbuf "yes or no expected"
	  end
      | "InvariantPolicy" ->
	  begin
	    Java_options.inv_sem :=
	      match v with
		| "None" -> Jc_env.InvNone
		| "Arguments" -> Jc_env.InvArguments
		| "Ownership" -> Jc_env.InvOwnership
		| _ -> lex_error lexbuf ("unknown invariant policy " ^ v)
	  end
      | "SeparationPolicy" ->
	  begin
	    Java_options.separation_policy :=
	      match v with
		| "None" -> Jc_env.SepNone
		| "Regions" -> Jc_env.SepRegions
		| _ -> lex_error lexbuf ("unknown separation policy " ^ v)
	  end
      | "NonNullByDefault" ->
	  begin
	    Java_options.nonnull_sem :=
	    match v with
	      | "none" -> Java_env.NonNullNone
	      | "fields" -> Java_env.NonNullFields
	      | "all" -> Java_env.NonNullAll
	      | "alllocal" -> Java_env.NonNullAllLocal
	      | _ -> lex_error lexbuf ("unknown nonnull policy " ^ v)
	  end
      | "MinimalClassHierarchy" ->
	  begin
	    match String.lowercase v with
	      | "yes" -> Java_options.minimal_class_hierarchy := true
	      | "no" -> Java_options.minimal_class_hierarchy := false
	      | _ -> lex_error lexbuf "yes or no expected"
	  end
      | _ -> lex_error lexbuf ("unknown pragma " ^ id)


# 279 "java/java_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\180\255\181\255\182\255\183\255\184\255\185\255\186\255\
    \187\255\188\255\004\000\081\000\110\000\078\000\224\255\225\255\
    \003\000\227\255\067\000\081\000\082\000\083\000\107\000\085\000\
    \086\000\108\000\109\000\171\000\244\255\245\255\196\000\254\000\
    \129\000\254\255\142\000\218\255\168\000\225\000\251\255\112\001\
    \253\255\248\255\138\000\162\000\117\001\139\000\250\255\163\000\
    \138\001\074\002\188\002\182\000\046\003\252\255\133\001\213\001\
    \121\003\242\255\197\255\045\002\144\003\104\001\216\255\239\255\
    \215\255\238\255\219\255\217\255\211\255\232\255\209\255\231\255\
    \113\000\230\255\122\000\123\000\123\000\229\255\214\255\203\255\
    \210\255\205\255\126\000\213\255\132\000\212\255\159\002\179\003\
    \178\002\206\003\240\003\202\255\201\255\013\004\051\004\032\003\
    \116\004\200\255\085\004\154\004\187\004\219\004\059\002\129\000\
    \133\000\195\255\229\004\012\003\252\004\154\003\034\005\067\005\
    \099\005\109\005\198\255\125\005\135\005\199\255\158\005\168\005\
    \191\005\214\005\196\255\157\000\246\005\011\006\139\004\209\004\
    \163\000\165\000\193\255\190\255\089\005\191\255\167\000\192\255\
    \169\000\066\006\089\006\127\006\170\000\189\255\194\255\062\004\
    \250\255\161\005\252\255\162\005\164\006\255\255\253\255\254\255\
    \200\000\251\255\080\001\254\255\165\000\255\255\177\003\249\255\
    \250\255\251\255\030\005\165\001\166\000\255\255\253\255\045\004\
    ";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\074\000\053\000\053\000\047\000\255\255\255\255\
    \029\000\255\255\027\000\048\000\035\000\022\000\021\000\020\000\
    \018\000\015\000\014\000\012\000\255\255\255\255\009\000\074\000\
    \019\000\255\255\000\000\255\255\255\255\006\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\002\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\008\000\
    \058\000\255\255\255\255\255\255\058\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \051\000\255\255\032\000\049\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\033\000\255\255\034\000\255\255\255\255\057\000\
    \255\255\255\255\054\000\255\255\255\255\255\255\055\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\060\000\255\255\060\000\
    \060\000\255\255\060\000\255\255\060\000\255\255\255\255\255\255\
    \060\000\255\255\255\255\255\255\057\000\255\255\057\000\255\255\
    \059\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\061\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\004\000\255\255\003\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\002\000\255\255\003\000\255\255\255\255\255\255\
    \255\255\255\255\003\000\001\000\005\000\255\255\255\255\255\255\
    ";
  Lexing.lex_default = 
   "\002\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\123\000\255\255\255\255\255\255\000\000\000\000\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\255\255\255\255\
    \255\255\000\000\255\255\000\000\042\000\255\255\000\000\255\255\
    \000\000\000\000\042\000\047\000\042\000\042\000\000\000\047\000\
    \047\000\047\000\047\000\047\000\047\000\000\000\047\000\255\255\
    \255\255\000\000\000\000\255\255\255\255\255\255\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\000\000\255\255\255\255\255\255\000\000\000\000\000\000\
    \000\000\000\000\255\255\000\000\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\000\000\000\000\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\255\255\000\000\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\000\000\000\000\145\000\
    \000\000\145\000\000\000\145\000\150\000\000\000\000\000\000\000\
    \154\000\000\000\154\000\000\000\255\255\000\000\162\000\000\000\
    \000\000\000\000\162\000\255\255\255\255\000\000\000\000\255\255\
    ";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\034\000\033\000\000\000\034\000\034\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \034\000\018\000\003\000\000\000\000\000\023\000\022\000\010\000\
    \009\000\008\000\024\000\026\000\028\000\025\000\027\000\032\000\
    \012\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\014\000\029\000\019\000\020\000\013\000\015\000\
    \080\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\005\000\031\000\004\000\016\000\030\000\
    \124\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\007\000\021\000\006\000\017\000\087\000\
    \079\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\081\000\082\000\074\000\075\000\072\000\
    \070\000\069\000\067\000\066\000\041\000\041\000\086\000\034\000\
    \063\000\065\000\034\000\034\000\087\000\091\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\088\000\088\000\
    \068\000\064\000\062\000\037\000\046\000\046\000\034\000\073\000\
    \036\000\044\000\041\000\086\000\044\000\044\000\086\000\078\000\
    \076\000\077\000\091\000\083\000\084\000\091\000\035\000\051\000\
    \046\000\085\000\051\000\051\000\142\000\104\000\089\000\104\000\
    \044\000\105\000\130\000\105\000\130\000\048\000\135\000\071\000\
    \133\000\141\000\155\000\086\000\157\000\165\000\051\000\000\000\
    \000\000\057\000\091\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\104\000\089\000\104\000\
    \043\000\105\000\039\000\105\000\000\000\039\000\039\000\000\000\
    \000\000\000\000\156\000\050\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\000\000\000\000\
    \001\000\039\000\000\000\000\000\255\255\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\000\000\
    \000\000\038\000\000\000\030\000\000\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\000\000\255\255\000\000\000\000\055\000\000\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\039\000\255\255\000\000\039\000\039\000\044\000\041\000\
    \000\000\044\000\044\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\000\000\000\000\054\000\053\000\
    \039\000\054\000\054\000\048\000\046\000\044\000\048\000\048\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\255\255\255\255\000\000\054\000\000\000\000\000\
    \255\255\000\000\048\000\000\000\000\000\000\000\167\000\000\000\
    \040\000\167\000\167\000\000\000\000\000\045\000\255\255\000\000\
    \000\000\000\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\000\000\167\000\000\000\000\000\
    \153\000\000\000\000\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\166\000\000\000\000\000\
    \000\000\049\000\000\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \000\000\000\000\000\000\000\000\055\000\000\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \255\255\000\000\000\000\051\000\046\000\000\000\051\000\051\000\
    \061\000\000\000\061\000\000\000\000\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\000\000\
    \000\000\000\000\051\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\101\000\255\255\000\000\000\000\
    \000\000\000\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\000\000\255\255\000\000\050\000\
    \000\000\000\000\255\255\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\000\000\000\000\000\000\
    \000\000\049\000\000\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\050\000\046\000\000\000\
    \050\000\050\000\121\000\000\000\121\000\000\000\000\000\120\000\
    \120\000\120\000\120\000\120\000\120\000\120\000\120\000\120\000\
    \120\000\000\000\000\000\000\000\050\000\000\000\000\000\000\000\
    \087\000\000\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\000\000\086\000\
    \000\000\000\000\000\000\000\000\000\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\086\000\
    \000\000\000\000\000\000\052\000\000\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\054\000\
    \053\000\000\000\054\000\054\000\106\000\106\000\106\000\106\000\
    \106\000\106\000\106\000\106\000\106\000\106\000\000\000\000\000\
    \000\000\000\000\255\255\109\000\000\000\109\000\054\000\000\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \108\000\108\000\000\000\000\000\000\000\000\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\000\000\000\000\000\000\000\000\052\000\000\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\163\000\255\255\058\000\059\000\058\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \108\000\108\000\108\000\108\000\058\000\000\000\058\000\000\000\
    \000\000\000\000\000\000\164\000\000\000\058\000\059\000\058\000\
    \160\000\117\000\000\000\116\000\116\000\116\000\116\000\116\000\
    \116\000\116\000\116\000\116\000\116\000\000\000\000\000\000\000\
    \000\000\161\000\000\000\000\000\058\000\000\000\058\000\114\000\
    \115\000\114\000\000\000\000\000\093\000\000\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\000\000\000\000\114\000\
    \115\000\114\000\000\000\000\000\000\000\000\000\087\000\000\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \088\000\088\000\000\000\000\000\000\000\000\000\255\255\094\000\
    \094\000\094\000\094\000\094\000\094\000\086\000\167\000\000\000\
    \000\000\167\000\167\000\000\000\092\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\110\000\110\000\110\000\000\000\
    \146\000\000\000\000\000\147\000\000\000\167\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\000\000\086\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\092\000\000\000\000\000\000\000\
    \149\000\096\000\000\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\166\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\000\000\000\000\000\000\000\000\000\000\097\000\
    \107\000\000\000\107\000\095\000\000\000\106\000\106\000\106\000\
    \106\000\106\000\106\000\106\000\106\000\106\000\106\000\000\000\
    \000\000\000\000\000\000\000\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\148\000\000\000\000\000\000\000\000\000\097\000\
    \000\000\000\000\000\000\095\000\099\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\099\000\099\000\000\000\000\000\
    \000\000\159\000\131\000\000\000\000\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\000\000\098\000\000\000\000\000\000\000\
    \000\000\000\000\099\000\099\000\099\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\000\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\099\000\099\000\099\000\099\000\
    \099\000\000\000\000\000\000\000\098\000\000\000\102\000\000\000\
    \102\000\000\000\100\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\101\000\000\000\000\000\000\000\
    \131\000\000\000\000\000\099\000\099\000\099\000\099\000\099\000\
    \099\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \132\000\000\000\100\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\101\000\106\000\106\000\106\000\
    \106\000\106\000\106\000\106\000\106\000\106\000\106\000\103\000\
    \000\000\103\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\103\000\000\000\103\000\108\000\108\000\108\000\108\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\144\000\103\000\
    \105\000\103\000\105\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\103\000\000\000\103\000\000\000\255\255\000\000\000\000\
    \000\000\000\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\000\000\000\000\255\255\000\000\
    \105\000\000\000\105\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\000\000\000\000\000\000\000\000\000\000\113\000\000\000\
    \113\000\000\000\111\000\112\000\112\000\112\000\112\000\112\000\
    \112\000\112\000\112\000\112\000\112\000\000\000\000\000\000\000\
    \133\000\000\000\000\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\000\000\111\000\112\000\112\000\112\000\112\000\112\000\
    \112\000\112\000\112\000\112\000\112\000\112\000\112\000\112\000\
    \112\000\112\000\112\000\112\000\112\000\112\000\112\000\104\000\
    \119\000\104\000\119\000\255\255\255\255\118\000\118\000\118\000\
    \118\000\118\000\118\000\118\000\118\000\118\000\118\000\116\000\
    \116\000\116\000\116\000\116\000\116\000\116\000\116\000\116\000\
    \116\000\000\000\000\000\255\255\255\255\000\000\000\000\104\000\
    \000\000\104\000\000\000\114\000\115\000\114\000\118\000\118\000\
    \118\000\118\000\118\000\118\000\118\000\118\000\118\000\118\000\
    \118\000\118\000\118\000\118\000\118\000\118\000\118\000\118\000\
    \118\000\118\000\114\000\000\000\114\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\114\000\115\000\114\000\000\000\120\000\
    \120\000\120\000\120\000\120\000\120\000\120\000\120\000\120\000\
    \120\000\000\000\000\000\000\000\000\000\255\255\255\255\000\000\
    \000\000\000\000\114\000\122\000\114\000\122\000\120\000\120\000\
    \120\000\120\000\120\000\120\000\120\000\120\000\120\000\120\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \128\000\000\000\000\000\000\000\000\000\129\000\255\255\000\000\
    \000\000\000\000\000\000\122\000\000\000\122\000\127\000\127\000\
    \127\000\127\000\126\000\126\000\126\000\126\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\137\000\137\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\128\000\000\000\000\000\000\000\000\000\000\000\
    \128\000\000\000\000\000\000\000\128\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\128\000\000\000\000\000\000\000\
    \128\000\000\000\128\000\125\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\138\000\138\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \000\000\255\255\255\255\138\000\138\000\138\000\138\000\138\000\
    \138\000\000\000\000\000\000\000\000\000\000\000\000\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\000\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\151\000\000\000\
    \000\000\000\000\000\000\151\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \151\000\000\000\000\000\000\000\000\000\000\000\151\000\000\000\
    \000\000\000\000\151\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\151\000\000\000\000\000\000\000\151\000\000\000\
    \151\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\255\255\255\255\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \016\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\011\000\
    \018\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\013\000\013\000\019\000\019\000\020\000\
    \021\000\022\000\023\000\024\000\042\000\045\000\011\000\034\000\
    \026\000\025\000\034\000\034\000\012\000\011\000\012\000\012\000\
    \012\000\012\000\012\000\012\000\012\000\012\000\012\000\012\000\
    \022\000\025\000\026\000\032\000\043\000\047\000\034\000\072\000\
    \032\000\036\000\036\000\012\000\036\000\036\000\011\000\074\000\
    \075\000\076\000\012\000\082\000\082\000\011\000\032\000\051\000\
    \051\000\084\000\051\000\051\000\123\000\103\000\012\000\103\000\
    \036\000\104\000\128\000\104\000\129\000\043\000\134\000\021\000\
    \136\000\140\000\152\000\012\000\156\000\164\000\051\000\255\255\
    \255\255\027\000\012\000\027\000\027\000\027\000\027\000\027\000\
    \027\000\027\000\027\000\027\000\027\000\103\000\012\000\103\000\
    \036\000\104\000\037\000\104\000\255\255\037\000\037\000\255\255\
    \255\255\255\255\152\000\051\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\255\255\255\255\
    \000\000\037\000\255\255\255\255\010\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\255\255\
    \255\255\037\000\255\255\030\000\255\255\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\255\255\154\000\255\255\255\255\031\000\255\255\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\039\000\154\000\255\255\039\000\039\000\044\000\044\000\
    \255\255\044\000\044\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\042\000\045\000\255\255\255\255\054\000\054\000\
    \039\000\054\000\054\000\048\000\048\000\044\000\048\000\048\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\043\000\047\000\255\255\054\000\255\255\255\255\
    \036\000\255\255\048\000\255\255\255\255\255\255\163\000\255\255\
    \039\000\163\000\163\000\255\255\255\255\044\000\051\000\255\255\
    \255\255\255\255\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\255\255\163\000\255\255\255\255\
    \152\000\255\255\255\255\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\163\000\255\255\255\255\
    \255\255\048\000\255\255\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \255\255\255\255\255\255\255\255\055\000\255\255\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \154\000\255\255\255\255\049\000\049\000\255\255\049\000\049\000\
    \059\000\255\255\059\000\255\255\255\255\059\000\059\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\255\255\
    \255\255\255\255\049\000\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\102\000\044\000\255\255\255\255\
    \255\255\255\255\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\255\255\054\000\255\255\049\000\
    \255\255\255\255\048\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\255\255\255\255\255\255\
    \255\255\049\000\255\255\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\050\000\050\000\255\255\
    \050\000\050\000\086\000\255\255\086\000\255\255\255\255\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\255\255\255\255\255\255\050\000\255\255\255\255\255\255\
    \088\000\255\255\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\255\255\088\000\
    \255\255\255\255\255\255\255\255\255\255\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\088\000\
    \255\255\255\255\255\255\050\000\255\255\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\052\000\
    \052\000\255\255\052\000\052\000\107\000\107\000\107\000\107\000\
    \107\000\107\000\107\000\107\000\107\000\107\000\255\255\255\255\
    \255\255\255\255\049\000\095\000\255\255\095\000\052\000\255\255\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \095\000\095\000\255\255\255\255\255\255\255\255\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\255\255\255\255\255\255\255\255\052\000\255\255\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\158\000\050\000\056\000\056\000\056\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\109\000\109\000\109\000\109\000\109\000\109\000\
    \109\000\109\000\109\000\109\000\060\000\255\255\060\000\255\255\
    \255\255\255\255\255\255\158\000\255\255\056\000\056\000\056\000\
    \158\000\087\000\255\255\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\255\255\255\255\255\255\
    \255\255\158\000\255\255\255\255\060\000\255\255\060\000\087\000\
    \087\000\087\000\255\255\255\255\089\000\255\255\089\000\089\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\089\000\
    \089\000\089\000\089\000\089\000\089\000\255\255\255\255\087\000\
    \087\000\087\000\255\255\255\255\255\255\255\255\090\000\255\255\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\255\255\255\255\255\255\255\255\052\000\089\000\
    \089\000\089\000\089\000\089\000\089\000\090\000\167\000\255\255\
    \255\255\167\000\167\000\255\255\090\000\093\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\093\000\093\000\093\000\255\255\
    \143\000\255\255\255\255\143\000\255\255\167\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\255\255\090\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\090\000\255\255\255\255\255\255\
    \143\000\094\000\255\255\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\167\000\093\000\093\000\
    \093\000\093\000\093\000\093\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\255\255\255\255\255\255\255\255\255\255\094\000\
    \098\000\255\255\098\000\094\000\255\255\098\000\098\000\098\000\
    \098\000\098\000\098\000\098\000\098\000\098\000\098\000\255\255\
    \255\255\255\255\255\255\255\255\094\000\094\000\094\000\094\000\
    \094\000\094\000\143\000\255\255\255\255\255\255\255\255\094\000\
    \255\255\255\255\255\255\094\000\096\000\096\000\096\000\096\000\
    \096\000\096\000\096\000\096\000\096\000\096\000\255\255\255\255\
    \255\255\158\000\126\000\255\255\255\255\096\000\096\000\096\000\
    \096\000\096\000\096\000\126\000\126\000\126\000\126\000\126\000\
    \126\000\126\000\126\000\255\255\096\000\255\255\255\255\255\255\
    \255\255\255\255\099\000\099\000\099\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\255\255\096\000\096\000\096\000\
    \096\000\096\000\096\000\099\000\099\000\099\000\099\000\099\000\
    \099\000\255\255\255\255\255\255\096\000\255\255\100\000\255\255\
    \100\000\255\255\099\000\100\000\100\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\100\000\100\000\255\255\255\255\255\255\
    \127\000\255\255\255\255\099\000\099\000\099\000\099\000\099\000\
    \099\000\127\000\127\000\127\000\127\000\127\000\127\000\127\000\
    \127\000\255\255\099\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\101\000\106\000\106\000\106\000\
    \106\000\106\000\106\000\106\000\106\000\106\000\106\000\101\000\
    \255\255\101\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \162\000\106\000\255\255\106\000\108\000\108\000\108\000\108\000\
    \108\000\108\000\108\000\108\000\108\000\108\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\143\000\101\000\
    \108\000\101\000\108\000\255\255\255\255\255\255\255\255\255\255\
    \162\000\106\000\255\255\106\000\255\255\162\000\255\255\255\255\
    \255\255\255\255\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\255\255\255\255\162\000\255\255\
    \108\000\255\255\108\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\255\255\255\255\255\255\255\255\255\255\111\000\255\255\
    \111\000\255\255\110\000\111\000\111\000\111\000\111\000\111\000\
    \111\000\111\000\111\000\111\000\111\000\255\255\255\255\255\255\
    \132\000\255\255\255\255\110\000\110\000\110\000\110\000\110\000\
    \110\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \132\000\255\255\110\000\112\000\112\000\112\000\112\000\112\000\
    \112\000\112\000\112\000\112\000\112\000\113\000\113\000\113\000\
    \113\000\113\000\113\000\113\000\113\000\113\000\113\000\112\000\
    \115\000\112\000\115\000\145\000\147\000\115\000\115\000\115\000\
    \115\000\115\000\115\000\115\000\115\000\115\000\115\000\116\000\
    \116\000\116\000\116\000\116\000\116\000\116\000\116\000\116\000\
    \116\000\255\255\255\255\145\000\147\000\255\255\255\255\112\000\
    \255\255\112\000\255\255\116\000\116\000\116\000\118\000\118\000\
    \118\000\118\000\118\000\118\000\118\000\118\000\118\000\118\000\
    \119\000\119\000\119\000\119\000\119\000\119\000\119\000\119\000\
    \119\000\119\000\118\000\255\255\118\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\116\000\116\000\116\000\255\255\120\000\
    \120\000\120\000\120\000\120\000\120\000\120\000\120\000\120\000\
    \120\000\255\255\255\255\255\255\255\255\145\000\147\000\255\255\
    \255\255\255\255\118\000\120\000\118\000\120\000\121\000\121\000\
    \121\000\121\000\121\000\121\000\121\000\121\000\121\000\121\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \124\000\255\255\255\255\255\255\255\255\124\000\162\000\255\255\
    \255\255\255\255\255\255\120\000\255\255\120\000\124\000\124\000\
    \124\000\124\000\124\000\124\000\124\000\124\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\125\000\125\000\125\000\125\000\125\000\
    \125\000\125\000\125\000\125\000\125\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\125\000\125\000\125\000\125\000\
    \125\000\125\000\124\000\255\255\255\255\255\255\255\255\255\255\
    \124\000\255\255\255\255\255\255\124\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\124\000\255\255\255\255\255\255\
    \124\000\255\255\124\000\124\000\125\000\125\000\125\000\125\000\
    \125\000\125\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\137\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\137\000\137\000\137\000\137\000\137\000\
    \137\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\138\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\138\000\138\000\138\000\138\000\138\000\138\000\
    \255\255\145\000\147\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\255\255\255\255\255\255\255\255\255\255\255\255\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\255\255\138\000\138\000\138\000\138\000\138\000\138\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\148\000\255\255\
    \255\255\255\255\255\255\148\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \139\000\139\000\139\000\139\000\139\000\139\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \148\000\255\255\255\255\255\255\255\255\255\255\148\000\255\255\
    \255\255\255\255\148\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\148\000\255\255\255\255\255\255\148\000\255\255\
    \148\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\148\000";
  Lexing.lex_base_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\001\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \010\000\085\000\199\000\007\000\018\001\023\000\000\000\000\000\
    \165\000\000\000\037\000\184\000\093\001\103\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\113\001\123\001\
    \023\000\000\000\024\000\000\000\000\000\000\000\000\000\133\001\
    \000\000\000\000\143\001\000\000\153\001\163\001\173\001\004\000\
    \000\000\067\000\186\001\196\001\218\001\228\001\000\000\241\001\
    \251\001\005\002\084\000\018\002\028\002\000\000\050\002\060\002\
    \070\002\080\002\094\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_backtrk_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \032\000\000\000\000\000\000\000\032\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\047\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\057\000\000\000\067\000\
    \072\000\000\000\057\000\000\000\057\000\000\000\000\000\000\000\
    \057\000\000\000\000\000\000\000\047\000\000\000\047\000\000\000\
    \089\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_default_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_trans_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\011\000\000\000\000\000\011\000\011\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\011\000\011\000\000\000\000\000\001\000\001\000\
    \006\000\006\000\006\000\006\000\006\000\006\000\006\000\006\000\
    \006\000\006\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\017\000\001\000\001\000\000\000\
    \052\000\000\000\052\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\000\000\000\000\000\000\
    \052\000\014\000\052\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\000\000\
    \000\000\000\000\017\000\000\000\000\000\000\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \000\000\000\000\000\000\000\000\014\000\000\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \017\000\000\000\000\000\017\000\017\000\006\000\006\000\006\000\
    \006\000\006\000\006\000\006\000\006\000\006\000\006\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\017\000\
    \006\000\006\000\006\000\006\000\006\000\006\000\006\000\006\000\
    \006\000\006\000\000\000\000\000\000\000\000\000\000\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\000\000\000\000\000\000\000\000\020\000\000\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\000\000\000\000\000\000\
    \000\000\020\000\000\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\006\000\006\000\006\000\
    \006\000\006\000\006\000\006\000\006\000\006\000\006\000\006\000\
    \006\000\006\000\006\000\006\000\006\000\006\000\006\000\006\000\
    \006\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\062\000\
    \000\000\062\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\062\000\000\000\
    \062\000\000\000\000\000\000\000\000\000\000\000\000\000\062\000\
    \000\000\062\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\062\000\000\000\
    \062\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\077\000\
    \000\000\077\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\077\000\
    \000\000\077\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_check_code = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\048\000\255\255\255\255\048\000\048\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\048\000\043\000\255\255\255\255\011\000\012\000\
    \027\000\027\000\027\000\027\000\027\000\027\000\027\000\027\000\
    \027\000\027\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\051\000\088\000\090\000\255\255\
    \103\000\255\255\103\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\255\255\255\255\255\255\
    \103\000\048\000\103\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\255\255\
    \255\255\255\255\049\000\255\255\255\255\255\255\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \255\255\255\255\255\255\255\255\049\000\255\255\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \050\000\255\255\255\255\050\000\050\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\056\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\050\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\255\255\255\255\255\255\255\255\255\255\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\255\255\255\255\255\255\255\255\050\000\255\255\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\255\255\255\255\255\255\
    \255\255\052\000\255\255\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\061\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\095\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\098\000\
    \098\000\098\000\098\000\098\000\098\000\098\000\098\000\098\000\
    \098\000\100\000\100\000\100\000\100\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\101\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\102\000\102\000\102\000\101\000\
    \255\255\101\000\106\000\106\000\106\000\106\000\106\000\106\000\
    \106\000\106\000\106\000\106\000\107\000\107\000\107\000\107\000\
    \107\000\107\000\107\000\107\000\107\000\107\000\106\000\255\255\
    \106\000\255\255\255\255\255\255\255\255\255\255\255\255\101\000\
    \255\255\101\000\108\000\108\000\108\000\108\000\108\000\108\000\
    \108\000\108\000\108\000\108\000\109\000\109\000\109\000\109\000\
    \109\000\109\000\109\000\109\000\109\000\109\000\106\000\255\255\
    \106\000\111\000\111\000\111\000\111\000\111\000\111\000\111\000\
    \111\000\111\000\111\000\112\000\112\000\112\000\112\000\112\000\
    \112\000\112\000\112\000\112\000\112\000\113\000\113\000\113\000\
    \113\000\113\000\113\000\113\000\113\000\113\000\113\000\112\000\
    \255\255\112\000\115\000\115\000\115\000\115\000\115\000\115\000\
    \115\000\115\000\115\000\115\000\116\000\116\000\116\000\116\000\
    \116\000\116\000\116\000\116\000\116\000\116\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\112\000\
    \255\255\112\000\118\000\118\000\118\000\118\000\118\000\118\000\
    \118\000\118\000\118\000\118\000\119\000\119\000\119\000\119\000\
    \119\000\119\000\119\000\119\000\119\000\119\000\120\000\120\000\
    \120\000\120\000\120\000\120\000\120\000\120\000\120\000\120\000\
    \121\000\121\000\121\000\121\000\121\000\121\000\121\000\121\000\
    \121\000\121\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_code = 
   "\255\011\255\010\255\255\009\255\008\255\255\004\255\255\005\255\
    \255\006\255\255\007\255\255\002\006\003\007\000\004\001\005\255\
    \001\255\000\008\255\001\009\000\008\255\016\255\015\255\255\001\
    \255\000\010\255\013\255\012\255\255\001\255\000\012\255\014\255\
    \012\255\255\001\013\000\012\255\001\014\000\012\255\014\013\013\
    \255\012\255\255\001\011\000\010\255\001\255\000\015\255\001\016\
    \000\015\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.create 17 (-1) ;   __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 334 "java/java_lexer.mll"
      ( token lexbuf )
# 1144 "java/java_lexer.ml"

  | 1 ->
# 336 "java/java_lexer.mll"
      ( newline lexbuf; token lexbuf )
# 1149 "java/java_lexer.ml"

  | 2 ->
# 338 "java/java_lexer.mll"
      ( lex_error lexbuf "no space allowed between /* and @" )
# 1154 "java/java_lexer.ml"

  | 3 ->
let
# 339 "java/java_lexer.mll"
                                 id
# 1160 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 340 "java/java_lexer.mll"
                              v
# 1165 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(2) lexbuf.Lexing.lex_mem.(3) in
# 341 "java/java_lexer.mll"
      ( pragma lexbuf id v; newline lexbuf; token lexbuf )
# 1169 "java/java_lexer.ml"

  | 4 ->
# 343 "java/java_lexer.mll"
      ( let loc = lexeme_start_p lexbuf in
	Buffer.clear buf; ANNOT(loc, annot lexbuf) )
# 1175 "java/java_lexer.ml"

  | 5 ->
let
# 345 "java/java_lexer.mll"
                        a
# 1181 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf (lexbuf.Lexing.lex_start_pos + 3) (lexbuf.Lexing.lex_curr_pos + -1) in
# 346 "java/java_lexer.mll"
      ( let loc = lexeme_start_p lexbuf in
	newline lexbuf;	ANNOT(loc,a) )
# 1186 "java/java_lexer.ml"

  | 6 ->
# 349 "java/java_lexer.mll"
      ( comment lexbuf; token lexbuf )
# 1191 "java/java_lexer.ml"

  | 7 ->
# 351 "java/java_lexer.mll"
      ( newline lexbuf; token lexbuf )
# 1196 "java/java_lexer.ml"

  | 8 ->
let
# 352 "java/java_lexer.mll"
                          id
# 1202 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 353 "java/java_lexer.mll"
      ( special_id lexbuf id )
# 1206 "java/java_lexer.ml"

  | 9 ->
let
# 354 "java/java_lexer.mll"
                     id
# 1212 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 355 "java/java_lexer.mll"
      ( id_or_kw id )
# 1216 "java/java_lexer.ml"

  | 10 ->
# 357 "java/java_lexer.mll"
      ( SEMICOLON )
# 1221 "java/java_lexer.ml"

  | 11 ->
# 359 "java/java_lexer.mll"
      ( COMMA )
# 1226 "java/java_lexer.ml"

  | 12 ->
# 361 "java/java_lexer.mll"
      ( DOT )
# 1231 "java/java_lexer.ml"

  | 13 ->
# 363 "java/java_lexer.mll"
      ( DOTDOT )
# 1236 "java/java_lexer.ml"

  | 14 ->
# 365 "java/java_lexer.mll"
      ( PLUS )
# 1241 "java/java_lexer.ml"

  | 15 ->
# 367 "java/java_lexer.mll"
      ( MINUS )
# 1246 "java/java_lexer.ml"

  | 16 ->
# 369 "java/java_lexer.mll"
      ( PLUSPLUS )
# 1251 "java/java_lexer.ml"

  | 17 ->
# 371 "java/java_lexer.mll"
      ( MINUSMINUS )
# 1256 "java/java_lexer.ml"

  | 18 ->
# 373 "java/java_lexer.mll"
      ( STAR )
# 1261 "java/java_lexer.ml"

  | 19 ->
# 375 "java/java_lexer.mll"
      ( SLASH )
# 1266 "java/java_lexer.ml"

  | 20 ->
# 377 "java/java_lexer.mll"
      ( PERCENT )
# 1271 "java/java_lexer.ml"

  | 21 ->
# 379 "java/java_lexer.mll"
      ( AMPERSAND )
# 1276 "java/java_lexer.ml"

  | 22 ->
# 381 "java/java_lexer.mll"
      ( VERTICALBAR )
# 1281 "java/java_lexer.ml"

  | 23 ->
# 383 "java/java_lexer.mll"
      ( AMPERSANDAMPERSAND )
# 1286 "java/java_lexer.ml"

  | 24 ->
# 385 "java/java_lexer.mll"
      ( VERTICALBARVERTICALBAR )
# 1291 "java/java_lexer.ml"

  | 25 ->
# 387 "java/java_lexer.mll"
      ( EQEQGT )
# 1296 "java/java_lexer.ml"

  | 26 ->
# 389 "java/java_lexer.mll"
      ( LTEQEQGT )
# 1301 "java/java_lexer.ml"

  | 27 ->
# 391 "java/java_lexer.mll"
      ( BANG )
# 1306 "java/java_lexer.ml"

  | 28 ->
# 393 "java/java_lexer.mll"
      ( TILDA )
# 1311 "java/java_lexer.ml"

  | 29 ->
# 395 "java/java_lexer.mll"
      ( CARET )
# 1316 "java/java_lexer.ml"

  | 30 ->
# 397 "java/java_lexer.mll"
      ( QUESTIONMARK )
# 1321 "java/java_lexer.ml"

  | 31 ->
# 399 "java/java_lexer.mll"
      ( COLON )
# 1326 "java/java_lexer.ml"

  | 32 ->
# 401 "java/java_lexer.mll"
      ( SHIFT Blsl )
# 1331 "java/java_lexer.ml"

  | 33 ->
# 403 "java/java_lexer.mll"
      ( SHIFT Blsr )
# 1336 "java/java_lexer.ml"

  | 34 ->
# 405 "java/java_lexer.mll"
      ( SHIFT Basr )
# 1341 "java/java_lexer.ml"

  | 35 ->
# 407 "java/java_lexer.mll"
      ( EQ )
# 1346 "java/java_lexer.ml"

  | 36 ->
# 409 "java/java_lexer.mll"
      ( ASSIGNOP Bmul )
# 1351 "java/java_lexer.ml"

  | 37 ->
# 411 "java/java_lexer.mll"
      ( ASSIGNOP Bdiv )
# 1356 "java/java_lexer.ml"

  | 38 ->
# 413 "java/java_lexer.mll"
      ( ASSIGNOP Bmod )
# 1361 "java/java_lexer.ml"

  | 39 ->
# 415 "java/java_lexer.mll"
      ( ASSIGNOP Badd )
# 1366 "java/java_lexer.ml"

  | 40 ->
# 417 "java/java_lexer.mll"
      ( ASSIGNOP Bsub )
# 1371 "java/java_lexer.ml"

  | 41 ->
# 419 "java/java_lexer.mll"
      ( ASSIGNOP Blsl )
# 1376 "java/java_lexer.ml"

  | 42 ->
# 421 "java/java_lexer.mll"
      ( ASSIGNOP Blsr )
# 1381 "java/java_lexer.ml"

  | 43 ->
# 423 "java/java_lexer.mll"
      ( ASSIGNOP Basr )
# 1386 "java/java_lexer.ml"

  | 44 ->
# 425 "java/java_lexer.mll"
      ( ASSIGNOP Bbwand )
# 1391 "java/java_lexer.ml"

  | 45 ->
# 427 "java/java_lexer.mll"
      ( ASSIGNOP Bbwxor )
# 1396 "java/java_lexer.ml"

  | 46 ->
# 429 "java/java_lexer.mll"
      ( ASSIGNOP Bbwor )
# 1401 "java/java_lexer.ml"

  | 47 ->
# 431 "java/java_lexer.mll"
      ( GT )
# 1406 "java/java_lexer.ml"

  | 48 ->
# 433 "java/java_lexer.mll"
      ( LT )
# 1411 "java/java_lexer.ml"

  | 49 ->
# 435 "java/java_lexer.mll"
      ( LE )
# 1416 "java/java_lexer.ml"

  | 50 ->
# 437 "java/java_lexer.mll"
      ( GE )
# 1421 "java/java_lexer.ml"

  | 51 ->
# 439 "java/java_lexer.mll"
      ( EQOP Beq )
# 1426 "java/java_lexer.ml"

  | 52 ->
# 441 "java/java_lexer.mll"
      ( EQOP Bne )
# 1431 "java/java_lexer.ml"

  | 53 ->
let
# 446 "java/java_lexer.mll"
                                      n
# 1437 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 447 "java/java_lexer.mll"
      ( INTCONSTANT n )
# 1441 "java/java_lexer.ml"

  | 54 ->
let
# 451 "java/java_lexer.mll"
                               n
# 1447 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 452 "java/java_lexer.mll"
      ( INTCONSTANT n )
# 1451 "java/java_lexer.ml"

  | 55 ->
let
# 456 "java/java_lexer.mll"
                               n
# 1457 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 457 "java/java_lexer.mll"
    ( INTCONSTANT n )
# 1461 "java/java_lexer.ml"

  | 56 ->
let
# 461 "java/java_lexer.mll"
            n
# 1467 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -2) in
# 461 "java/java_lexer.mll"
                            ( raise (Dotdot n) )
# 1471 "java/java_lexer.ml"

  | 57 ->
let
# 465 "java/java_lexer.mll"
                                             pre
# 1477 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 465 "java/java_lexer.mll"
                                                                    suf
# 1482 "java/java_lexer.ml"
= Lexing.sub_lexeme_char_opt lexbuf lexbuf.Lexing.lex_mem.(1) in
# 466 "java/java_lexer.mll"
      ( REALCONSTANT (pre,suf) )
# 1486 "java/java_lexer.ml"

  | 58 ->
let
# 468 "java/java_lexer.mll"
                                         pre
# 1492 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 468 "java/java_lexer.mll"
                                                                suf
# 1497 "java/java_lexer.ml"
= Lexing.sub_lexeme_char_opt lexbuf lexbuf.Lexing.lex_mem.(1) in
# 469 "java/java_lexer.mll"
      ( REALCONSTANT (pre,suf) )
# 1501 "java/java_lexer.ml"

  | 59 ->
let
# 471 "java/java_lexer.mll"
                                   pre
# 1507 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 471 "java/java_lexer.mll"
                                                          suf
# 1512 "java/java_lexer.ml"
= Lexing.sub_lexeme_char_opt lexbuf lexbuf.Lexing.lex_mem.(1) in
# 472 "java/java_lexer.mll"
      ( REALCONSTANT (pre,suf) )
# 1516 "java/java_lexer.ml"

  | 60 ->
let
# 474 "java/java_lexer.mll"
                                                           suf
# 1522 "java/java_lexer.ml"
= Lexing.sub_lexeme_char_opt lexbuf lexbuf.Lexing.lex_mem.(1)
and
# 476 "java/java_lexer.mll"
                            pre
# 1527 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0) in
# 477 "java/java_lexer.mll"
      ( REALCONSTANT (pre,suf) )
# 1531 "java/java_lexer.ml"

  | 61 ->
let
# 481 "java/java_lexer.mll"
                 s
# 1537 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 3) in
# 482 "java/java_lexer.mll"
      ( CHARACTER s )
# 1541 "java/java_lexer.ml"

  | 62 ->
let
# 484 "java/java_lexer.mll"
                                   s
# 1547 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 4) in
# 485 "java/java_lexer.mll"
      ( CHARACTER s )
# 1551 "java/java_lexer.ml"

  | 63 ->
let
# 487 "java/java_lexer.mll"
                                               s
# 1557 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 6) in
# 488 "java/java_lexer.mll"
      ( CHARACTER s )
# 1561 "java/java_lexer.ml"

  | 64 ->
let
# 490 "java/java_lexer.mll"
                                     s
# 1567 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 5) in
# 491 "java/java_lexer.mll"
      ( CHARACTER s )
# 1571 "java/java_lexer.ml"

  | 65 ->
let
# 493 "java/java_lexer.mll"
                           s
# 1577 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 4) in
# 494 "java/java_lexer.mll"
      ( CHARACTER s )
# 1581 "java/java_lexer.ml"

  | 66 ->
let
# 496 "java/java_lexer.mll"
                              s
# 1587 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 8) in
# 497 "java/java_lexer.mll"
      ( CHARACTER s )
# 1591 "java/java_lexer.ml"

  | 67 ->
# 500 "java/java_lexer.mll"
      ( LEFTPAR )
# 1596 "java/java_lexer.ml"

  | 68 ->
# 502 "java/java_lexer.mll"
      ( RIGHTPAR )
# 1601 "java/java_lexer.ml"

  | 69 ->
# 504 "java/java_lexer.mll"
      ( LEFTBRACE )
# 1606 "java/java_lexer.ml"

  | 70 ->
# 506 "java/java_lexer.mll"
      ( RIGHTBRACE )
# 1611 "java/java_lexer.ml"

  | 71 ->
# 508 "java/java_lexer.mll"
      ( LEFTBRACKET )
# 1616 "java/java_lexer.ml"

  | 72 ->
# 510 "java/java_lexer.mll"
      ( RIGHTBRACKET )
# 1621 "java/java_lexer.ml"

  | 73 ->
# 512 "java/java_lexer.mll"
      ( Buffer.clear buf; STRING(string lexbuf) )
# 1626 "java/java_lexer.ml"

  | 74 ->
# 514 "java/java_lexer.mll"
      ( lex_error lexbuf ("unexpected char `" ^ lexeme lexbuf ^ "'") )
# 1631 "java/java_lexer.ml"

  | 75 ->
# 516 "java/java_lexer.mll"
      ( EOF )
# 1636 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and string lexbuf =
    __ocaml_lex_string_rec lexbuf 143
and __ocaml_lex_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 520 "java/java_lexer.mll"
      ( Buffer.contents buf )
# 1647 "java/java_lexer.ml"

  | 1 ->
# 522 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf);
	string lexbuf )
# 1653 "java/java_lexer.ml"

  | 2 ->
# 525 "java/java_lexer.mll"
      ( lex_error lexbuf "unknown escape sequence in string" )
# 1658 "java/java_lexer.ml"

  | 3 ->
# 527 "java/java_lexer.mll"
      ( (* no \n anymore in strings since java 1.4 *)
	lex_error lexbuf "string not terminated"; )
# 1664 "java/java_lexer.ml"

  | 4 ->
# 530 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf); string lexbuf )
# 1669 "java/java_lexer.ml"

  | 5 ->
# 532 "java/java_lexer.mll"
      ( lex_error lexbuf "string not terminated" )
# 1674 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_string_rec lexbuf __ocaml_lex_state

and comment lexbuf =
    __ocaml_lex_comment_rec lexbuf 152
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 536 "java/java_lexer.mll"
      ( () )
# 1685 "java/java_lexer.ml"

  | 1 ->
# 538 "java/java_lexer.mll"
      ( newline lexbuf; comment lexbuf )
# 1690 "java/java_lexer.ml"

  | 2 ->
# 540 "java/java_lexer.mll"
      ( comment lexbuf )
# 1695 "java/java_lexer.ml"

  | 3 ->
# 542 "java/java_lexer.mll"
      ( comment lexbuf )
# 1700 "java/java_lexer.ml"

  | 4 ->
# 544 "java/java_lexer.mll"
      ( lex_error lexbuf "comment not terminated" )
# 1705 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

and annot lexbuf =
    __ocaml_lex_annot_rec lexbuf 158
and __ocaml_lex_annot_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 548 "java/java_lexer.mll"
      ( Buffer.contents buf )
# 1716 "java/java_lexer.ml"

  | 1 ->
# 550 "java/java_lexer.mll"
      ( newline lexbuf;
	Buffer.add_string buf (lexeme lexbuf);
	annot lexbuf )
# 1723 "java/java_lexer.ml"

  | 2 ->
let
# 553 "java/java_lexer.mll"
                    s
# 1729 "java/java_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -1) in
# 554 "java/java_lexer.mll"
      ( newline lexbuf;
	Buffer.add_string buf s;
	Buffer.add_char buf ' ';
	annot lexbuf )
# 1736 "java/java_lexer.ml"

  | 3 ->
# 559 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf);
	annot lexbuf )
# 1742 "java/java_lexer.ml"

  | 4 ->
# 562 "java/java_lexer.mll"
      ( annot lexbuf )
# 1747 "java/java_lexer.ml"

  | 5 ->
# 564 "java/java_lexer.mll"
      ( Buffer.add_string buf (lexeme lexbuf);
	annot lexbuf )
# 1753 "java/java_lexer.ml"

  | 6 ->
# 567 "java/java_lexer.mll"
      ( lex_error lexbuf "annotation not terminated" )
# 1758 "java/java_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_annot_rec lexbuf __ocaml_lex_state

;;

# 569 "java/java_lexer.mll"
 

let dotdot_mem = ref false

let next_token lexbuf =
  if !dotdot_mem then
    begin
      dotdot_mem := false;
      Format.eprintf "DOTDOT@.";
      DOTDOT
    end
  else
    begin
      try
	token lexbuf
      with
	Dotdot(n) ->
	  dotdot_mem := true;
	  INTCONSTANT n
    end

  let parse f c =
    let lb = from_channel c in
    lb.lex_curr_p <- { lb.lex_curr_p with pos_fname = f };
    try
      Java_parser.compilation_unit next_token lb
    with Parsing.Parse_error ->
      Java_options.parsing_error (loc lb) ""

  let parse_spec f c =
    let lb = from_channel c in
    lb.lex_curr_p <- { lb.lex_curr_p with pos_fname = f };
    try
      Java_parser.kml_spec_eof next_token lb
    with Parsing.Parse_error ->
      Java_options.parsing_error (loc lb) ""


# 1803 "java/java_lexer.ml"
